@@ -65,4 +65,13 @@ IRT.likelihood.rasch.mirtlc <- function( object , ... ){
 	attr(ll,"G") <- object$G
     return(ll)
         }
+##########################################################		
+# likelihood xxirt
+IRT.likelihood.xxirt <- function( object , ... ){    
+    ll <- object$p.xi.aj
+    attr(ll,"theta") <- object$Theta
+	attr(ll,"prob.theta") <- object$probs_Theta
+	attr(ll,"G") <- object$G	
+    return(ll)
+        }
 ##########################################################		
\ No newline at end of file
