@@ -4,7 +4,7 @@
 #####################################################################
 # converts a data frame in wide format into long format
 data.wide2long <- function( dat , id=NULL , X=NULL , Q=NULL){
-    items <- setdiff( colnames(dat) , id )
+    items <- base::setdiff( colnames(dat) , id )
     I <- length(items)
     N <- nrow(dat)
 #    dat1 <- matrix( as.matrix(dat[,items]) , nrow= N*I , ncol=1 , byrow=TRUE )
@@ -32,7 +32,7 @@ data.wide2long <- function( dat , id=NULL , X=NULL , Q=NULL){
 					Q <- as.data.frame(Q)
 					Q$item <- colnames(dat)
 							}
-		dat1 <- merge( x = dat1 , y = Q , by ="item" , all.x=TRUE )
+		dat1 <- base::merge( x = dat1 , y = Q , by ="item" , all.x=TRUE )
 					}
 	dat1 <- dat1[ order( 10000*dat1$id_index + dat1$item_index ) , ]		
 	dat1 <- data.frame( "rowindex" = 1:(N*I) , dat1 )
