@@ -14,7 +14,7 @@ likelihood_adjustment_compute <- function( likelihood, theta ,
 	# compute adjusted likelihood
 	like2 <- 0*likelihood
 	for (tt in 1:TP){
-		like2[,tt] <- dnorm( theta[tt] , mean=M1 , sd = SD1*adjfac*tuningfac )
+		like2[,tt] <- stats::dnorm( theta[tt] , mean=M1 , sd = SD1*adjfac*tuningfac )
 					}
     like2 <- like2 / rowSums(like2) * w1
     return(like2)
@@ -64,7 +64,7 @@ likelihood_adjustment_tuning <- function( likelihood , theta , thetaM , adjfac ,
 trait_normal_approx <- function( probs , theta ){
 	M <- sum( theta*probs )
 	SD <- sqrt( sum( theta^2*probs ) - M^2 )
-	probs1 <- dnorm( theta , mean=M , sd=SD)
+	probs1 <- stats::dnorm( theta , mean=M , sd=SD)
 	probs1 <- probs1/sum(probs1)			
 	return(probs1)
 			}
