@@ -4,7 +4,7 @@
 nedelsky.latresp <- function(K){
 	nodes <- c(0,1)
 	ndim <- K
-	combis <- as.matrix( expand.grid( as.data.frame( matrix( rep(nodes, ndim) , 
+	combis <- as.matrix( base::expand.grid( as.data.frame( matrix( rep(nodes, ndim) , 
             ncol = ndim ) ) ) )
 	return(combis)
 		}
\ No newline at end of file
